@@ -107,11 +107,7 @@ prodEmbed e = do
     return $ ComputedEntry (ebHaskellName e) st link
 
 toApp :: (Request -> IO Response) -> Application
-#if MIN_VERSION_wai(3, 0, 0)
 toApp f req g = f req >>= g
-#else
-toApp = id
-#endif
 
 tryExtraDevelFiles :: [[T.Text] -> IO (Maybe (MimeType, BL.ByteString))] -> Application
 tryExtraDevelFiles = toApp . tryExtraDevelFiles'
@@ -133,19 +129,11 @@ tryExtraDevelFiles' (f:fs) r = do
 
 -- | Helper to create the development application at runtime
 develApp :: StaticSettings -> [[T.Text] -> IO (Maybe (MimeType, BL.ByteString))] -> Application
-#if MIN_VERSION_wai(3, 0, 0)
 develApp settings extra req sendResponse = do
     staticApp settings {ssMaxAge = NoMaxAge} req $ \resp ->
         if statusCode (responseStatus resp) == 404
             then tryExtraDevelFiles extra req sendResponse
             else sendResponse resp
-#else
-develApp settings extra req = do
-    resp <- staticApp settings {ssMaxAge = NoMaxAge} req
-    if statusCode (responseStatus resp) == 404
-        then tryExtraDevelFiles extra req
-        else return resp
-#endif
 
 -- | The type of 'addStaticContent'
 type AddStaticContent site = T.Text -> T.Text -> BL.ByteString
